pub struct DptData {
pub depth_relative_to_transducer: Option<f64>,
pub transducer_offset: Option<f64>,
}Expand description
DPT - Depth of Water
Fields
depth_relative_to_transducer: Option<f64>Water depth relative to transducer, meters
transducer_offset: Option<f64>Offset from transducer, meters positive means distance from transducer to water line negative means distance from transducer to keel